==> clean_android_design-0.2.5.tar.gz: lib/src/router/navigator_widgets/dialog_navigator_widget.dart <==
import 'dart:math';

import 'package:clean_android_design/clean_android_design.dart';
import 'package:clean_android_design/src/router/custom_pages.dart';
import 'package:flutter/material.dart';

class DialogNavigatorWidget extends StatefulWidget {
  const DialogNavigatorWidget(
      {Key? key, required this.routePath, required this.notifyListeners})
      : super(key: key);

  final SplitRoutePath routePath;
  final void Function() notifyListeners;

  @override
  State<DialogNavigatorWidget> createState() => _DialogNavigatorWidgetState();
}

class _DialogNavigatorWidgetState extends State<DialogNavigatorWidget> {
  final ValueKey navigatorKey = ValueKey("Test");
  final ValueKey backgroundKey = ValueKey("dialog-background-key");

  @override
  Widget build(BuildContext context) {
    var showDialog = widget.routePath.pageInstances
        .any((x) => x.position == SplitRouterPosition.Dialog);

    if (!showDialog) return Container();

    return HeroControllerScope(
      controller: HeroController(),
      child: Navigator(
        key: navigatorKey,
        pages: [
          MaterialPage(
            key: ValueKey('Dialog Bottom'),
            child: Container(),
          ),
          BackgroundPage(ValueKey(Random().nextInt(5060).toString())),
          ...widget.routePath.pageInstances
              .where((i) => i.position == SplitRouterPosition.Dialog)
              .map((i) => DialogPage(i))
              .toList()
        ],
        onPopPage: (route, result) {
          if (!route.didPop(result)) {
            return false;
          }

          SplitRouterDelegate.instance.pop(SplitRouterPosition.Dialog);
          widget.notifyListeners();

          return true;
        },
      ),
    );
  }
}

==> clean_android_design-0.2.8.tar.gz: lib/src/router/navigator_widgets/dialog_navigator_widget.dart <==
import 'dart:math';

import 'package:clean_android_design/clean_android_design.dart';
import 'package:clean_android_design/src/router/custom_pages.dart';
import 'package:flutter/material.dart';

class DialogNavigatorWidget extends StatefulWidget {
  const DialogNavigatorWidget(
      {Key? key, required this.routePath, required this.notifyListeners})
      : super(key: key);

  final SplitRoutePath routePath;
  final void Function() notifyListeners;

  @override
  State<DialogNavigatorWidget> createState() => _DialogNavigatorWidgetState();
}

class _DialogNavigatorWidgetState extends State<DialogNavigatorWidget> {
  final ValueKey navigatorKey = ValueKey("Test");
  final ValueKey backgroundKey = ValueKey("dialog-background-key");

  @override
  Widget build(BuildContext context) {
    var showDialog = widget.routePath.pageInstances
        .any((x) => x.position == SplitRouterPosition.Dialog);

    if (!showDialog) return Container();

    return HeroControllerScope(
      controller: HeroController(),
      child: Navigator(
        key: navigatorKey,
        pages: [
          MaterialPage(
            key: ValueKey('Dialog Bottom'),
            child: Container(),
          ),
          BackgroundPage(ValueKey(Random().nextInt(5060).toString())),
          DialogPage(widget.routePath.pageInstances
              .where((i) => i.position == SplitRouterPosition.Dialog)
              .last)
        ],
        onPopPage: (route, result) {
          if (!route.didPop(result)) {
            return false;
          }

          SplitRouterDelegate.instance.pop(SplitRouterPosition.Dialog);
          widget.notifyListeners();

          return true;
        },
      ),
    );
  }
}
